Crate azalia_log

Crate azalia_log 

🐻‍❄️🪚 azalia-log

The log Rust crate provides a JSON-compat writer that mimics the output of Logstash and a beautiful prettified logger that is used in all Noelware products and services.

Modules

writerswriters
Represents a curated list of WriteFns and a default JSON visitor that can be collected from a BTreeMap structure.

Structs

WriteLayer
Represents a Layer for writing to a type that implements Write, with a optional WriteFn to go alongside with this type.

Traits

WriteFn
Represents a function-based trait to create a String buffer with pieces you might need. This shouldn’t be implemented directly, but can be written with the following function signature: