🐻❄️🪚 azalia-log
The log Rust crate provides a JSON-compat writer that mimics the output of Logstash and a beautiful prettified logger that is used in all Noelware products and services.
Modules
- writers
writers - Represents a curated list of
WriteFns and a default JSON visitor that can be collected from aBTreeMapstructure.
Structs
- Write
Layer - Represents a
Layerfor writing to a type that implementsWrite, with a optionalWriteFnto go alongside with this type.